==> vue-components-1.5.13.tgz: package/lib/modals/src/functions/showModal.rd.js <==
import { useInjectStyle as f } from "../../../shared/hooks/useInjectStyle.rd.js";
import { ref as x, createVNode as n } from "vue";
import "../../../node_modules/ant-design-vue/es/modal/index.rd.js";
/* empty css                                                             *//* empty css                                                                 *//* empty css                                                                  */import "../../../icons/circle/index.rd.js";
import h from "../ModalHeader.vue.rd.js";
import v from "../ModalFooter.vue.rd.js";
import "../../../spinners/index.rd.js";
import B from "../../../node_modules/ant-design-vue/es/modal/style/index.css.rd.js";
import $ from "../modal.scss.rd.js";
import I from "../../../spinners/src/AbsoluteLoader.vue.rd.js";
import P from "../../../icons/circle/WarningCircle.vue.rd.js";
import M from "../../../icons/circle/DangerCircle.vue.rd.js";
import q from "../../../icons/circle/SuccessCircle.vue.rd.js";
import N from "../../../icons/circle/InfoCircle.vue.rd.js";
import S from "../../../icons/circle/QuestionCircle.vue.rd.js";
import j from "../../../node_modules/ant-design-vue/es/modal/Modal.rd.js";
f(B, "ant-modal");
f($, "ant-modal-custom");
const Z = (o) => t(o, "confirm"), oo = (o) => t({
  ...o,
  type: "info"
}, "info"), no = (o) => t({
  ...o,
  type: "success"
}, "info"), ro = (o) => t({
  ...o,
  type: "danger"
}, "info"), eo = (o) => t({
  ...o,
  type: "warning"
}, "info");
function t(o, i) {
  const p = i == "info";
  o.onConfirm || (o.onConfirm = () => s());
  const {
    onConfirm: d,
    type: u = "question",
    onCancel: l,
    description: m,
    title: _,
    showCloseIcon: b = !1,
    onClose: k,
    modalWidth: c = "340px",
    okBtnProps: C,
    cancelBtnProps: g
  } = o, a = x(!1);
  let e, r;
  switch (u) {
    case "question":
      e = S, r = "primary";
      break;
    case "info":
      e = N, r = "primary";
      break;
    case "success":
      e = q, r = "primary";
      break;
    case "danger":
      e = M, r = "danger";
      break;
    case "warning":
      e = P, r = "warning", p && (r = "primary");
      break;
  }
  const y = () => n("div", {
    class: "dark:!bg-opacity-70 dark:border-1px dark:border-solid dark:border-slate-700 bg-surface overflow-hidden round-big"
  }, [n(I, {
    loading: a
  }, null), n("div", {
    class: "flexC px-4 pt-4"
  }, [n("div", {
    class: "flex-center"
  }, [n(e, {
    iconSize: "1.8em",
    class: "p-2 transition"
  }, null)]), n("div", {
    class: ""
  }, [n(h, {
    class: "pl-0",
    center: !0,
    headTitle: _,
    showCloseIcon: b,
    onClose: k
  }, null), m ? n("div", {
    class: "p-4 text-center"
  }, [n("p", {
    class: "text-muted"
  }, [m])]) : n("span", {
    class: "flex py-4"
  }, null), n(v, {
    center: !0,
    okBtnProps: {
      block: i == "info",
      customClass: "px-5",
      color: r,
      type: "filled",
      ...C
    },
    cancelBtnProps: g,
    onCancel: () => {
      l ? l(s) : s();
    },
    onAccept: () => d(a, () => {
      s(), setTimeout(() => {
        a.value = !1;
      }, 50);
    }),
    showCancelButton: i == "confirm"
  }, null)])])]), w = Number.isInteger(c) ? c + "px" : c, {
    destroy: s
  } = j.info({
    title: "",
    okCancel: !1,
    icon: void 0,
    width: w,
    okButtonProps: {
      disabled: !0
    },
    cancelButtonProps: {
      disabled: !0
    },
    class: "app-modal",
    content: y()
  });
}
export {
  Z as confirm,
  ro as danger,
  oo as info,
  t as showModal,
  no as success,
  eo as warning
};

==> vue-components-1.6.7.tgz: package/lib/modals/src/functions/showModal.rd.js <==
import { useInjectStyle as f } from "../../../shared/hooks/useInjectStyle.rd.js";
import { ref as y, createVNode as n } from "vue";
import "../../../node_modules/ant-design-vue/es/modal/index.rd.js";
/* empty css                                                             *//* empty css                                                                 *//* empty css                                                                  */import "../../../icons/circle/index.rd.js";
import x from "../ModalHeader.vue.rd.js";
import v from "../ModalFooter.vue.rd.js";
import "../../../spinners/index.rd.js";
import B from "../../../node_modules/ant-design-vue/es/modal/style/index.css.rd.js";
import $ from "../modal.scss.rd.js";
import I from "../../../spinners/src/AbsoluteLoader.vue.rd.js";
import P from "../../../icons/circle/WarningCircle.vue.rd.js";
import M from "../../../icons/circle/DangerCircle.vue.rd.js";
import S from "../../../icons/circle/SuccessCircle.vue.rd.js";
import q from "../../../icons/circle/InfoCircle.vue.rd.js";
import N from "../../../icons/circle/QuestionCircle.vue.rd.js";
import j from "../../../node_modules/ant-design-vue/es/modal/Modal.rd.js";
f(B, "ant-modal");
f($, "ant-modal-custom");
const Z = (o) => t(o, "confirm"), oo = (o) => t({
  ...o,
  type: "info"
}, "info"), no = (o) => t({
  ...o,
  type: "success"
}, "info"), eo = (o) => t({
  ...o,
  type: "danger"
}, "info"), ro = (o) => t({
  ...o,
  type: "warning"
}, "info");
function t(o, i) {
  const p = i == "info";
  o.onConfirm || (o.onConfirm = () => s());
  const {
    onConfirm: d,
    type: u = "question",
    onCancel: l,
    description: m,
    title: b,
    showCloseIcon: _ = !1,
    onClose: C,
    modalWidth: c = "340px",
    okBtnProps: g,
    cancelBtnProps: h
  } = o, a = y(!1);
  let r, e;
  switch (u) {
    case "question":
      r = N, e = "primary";
      break;
    case "info":
      r = q, e = "primary";
      break;
    case "success":
      r = S, e = "primary";
      break;
    case "danger":
      r = M, e = "danger";
      break;
    case "warning":
      r = P, e = "warning", p && (e = "primary");
      break;
  }
  const k = () => n("div", {
    class: "border-1 r-modal border-solid !border-theme border-theme bg-white dark:bg-rdSurface-800 overflow-hidden round-big"
  }, [n(I, {
    loading: a
  }, null), n("div", {
    class: "flexC px-4 pt-4"
  }, [n("div", {
    class: "flex-center"
  }, [n(r, {
    iconSize: "1.8em",
    class: "p-2 transition"
  }, null)]), n("div", {
    class: ""
  }, [n(x, {
    class: "pl-0 r-modal-header",
    center: !0,
    headTitle: b,
    showCloseIcon: _,
    onClose: C
  }, null), m ? n("div", {
    class: "p-4 text-center"
  }, [n("p", {
    class: "text-muted"
  }, [m])]) : n("span", {
    class: "flex py-4"
  }, null), n(v, {
    center: !0,
    okBtnProps: {
      block: i == "info",
      customClass: "px-5",
      color: e,
      type: "filled",
      ...g
    },
    cancelBtnProps: h,
    onCancel: () => {
      l ? l(s) : s();
    },
    onAccept: () => d(a, () => {
      s(), setTimeout(() => {
        a.value = !1;
      }, 50);
    }),
    showCancelButton: i == "confirm",
    class: "r-modal-footer"
  }, null)])])]), w = Number.isInteger(c) ? c + "px" : c, {
    destroy: s
  } = j.info({
    title: "",
    okCancel: !1,
    icon: void 0,
    width: w,
    okButtonProps: {
      disabled: !0
    },
    cancelButtonProps: {
      disabled: !0
    },
    class: "app-modal",
    content: k()
  });
}
export {
  Z as confirm,
  eo as danger,
  oo as info,
  t as showModal,
  no as success,
  ro as warning
};
